#!/usr/bin/env Rscript
# -*- coding: utf-8 -*-


#____________________________________________________________________________#
# R-code by  Steen W. Knudsen
# code to obtain rates from beast trees
# developed by using the R code from the study: 
# Knudsen, SW, Choat, HJ, Clements, KD (2019). The herbivorous fish family Kyphosidae (Teleostei: Perciformes) represents a recent radiation from higher latitudes. Journal of Biogeography 46, 2067-2080. https://doi.org/10.1111/jbi.13634 . 
# Using the supplemntary code files 08: 'read_BEAST_tree02.R'
# 
####################################################################################
# 
####################################################################################
#

#remove everything in the working environment, without a warning!!
rm(list=ls())

#https://groups.google.com/forum/#!topic/beast-users/Wpq2CU2Y5BQ  
#https://github.com/GuangchuangYu/treeio
## try http:// if https:// URLs are not supported
if (!requireNamespace("BiocManager", quietly=TRUE))
  install.packages("BiocManager")
## BiocManager::install("BiocUpgrade") ## you may need this
BiocManager::install("treeio")

# In a terminal first run
# $sudo apt-get install -y libgit2-dev 
#https://github.com/santiagosnchez/rBt
if(!require(devtools)){
  install.packages("devtools")
}  
library(devtools)

#install.packages("gert")
## install.packages("devtools")
#devtools::install_github("GuangchuangYu/treeio")

#install_github("santiagosnchez/rBt", force= TRUE)

#https://bioconductor.org/packages/devel/bioc/vignettes/treeio/inst/doc/Importer.html

# if(!require(ips)){
#   install.packages("ips", force =TRUE)
#   library(ips)
#   }

# if(!require(ape)){
#   install.packages("ape")
# }
# if(!require(colorspace)){
#   install.packages("colorspace")
# }
# if(!require(XML)){
#   install.packages("XML")
# }
# if(!require(phytools)){
#   install.packages("phytools")
# }
# if(!require(OutbreakTools)){
#   install.packages("OutbreakTools")
# }
# if(!require(paleotree)){
#   install.packages("paleotree")
# }
# 
# library(phyloch)
# library(strap)
# library(geoscale)
# library(OutbreakTools)
# library(ape)
# library(colorspace)
# library(XML)
# library(phytools)
# library(paleotree)
# 
# #install.packages
# if(!require(OutbreakTools)){
#   install.packages("OutbreakTools")
#   library(OutbreakTools)
# }
#install.packages
if(!require(ape)){
  install.packages("ape")
  library(ape)
} 


#install.packages
if(!require(treeio)){
  install.packages("treeio")
  library(treeio)
}

#install.packages
if(!require(tidytree)){
  install.packages("tidytree")
  library(tidytree)
}

require(treeio)
###########################################################################
#Package ‘RSvgDevice’ to prepare svg-files with editable text
if(!require(RSvgDevice)){
  install.packages("RSvgDevice")
  library(RSvgDevice)
}
# get ips package to be able to read beast nexus trees
if(!require(ips)){
  install.packages("ips")
  library(ips)
}

#install.packages
if(!require(tidyr)){
  install.packages("tidyr")
  library(tidyr)
}
citation("ape")

# install.packages("ggpubr")
# install.packages("cowplot")
# library(ggpubr)
# library(cowplot)
########################################################################################
#define working directory
wd00 <- "/Users/steenknudsen/Documents/Documents/KU_vejl_BSc_MSc_students/2020_aug_Iben_Stockholm/beast_tryout_2020dec"
wd00 <- "/home/hal9000/Iben_Stockholm_PDV"

setwd(wd00)
#define input directory
wd01 <- "PDVout10"
wd02 <- paste(wd00,"/",wd01,sep="")
#define output directory
wd03 <- "PDVout11_rates_from_BEASTtrees"
#define path and input directory
wd04 <- paste(wd00,"/",wd01,sep="")
#define path for new output directory
wd05 <- paste(wd00,"/",wd03,sep="")
#delete previous versions of the output directory
unlink(wd05, recursive=TRUE)
#create new directory
dir.create(wd05)
#define input file to read in
inpf01 <- "PDVpos12_scdccpnoeHKYF.comb.tre"
#notice that only the trees run in a relaxed clock model setting has 
# rates on the branches. The trees with strict clock models do not have rates
# on the branches
inpf01 <- "PDVpos12_rcdcbsnoeGTRF.comb.tre"
wd04_inpf01 <- paste(wd04,"/",inpf01,sep="")
#read in the be beast tree with the ips package
bt_in01 <- ips:::read.beast.table(wd04_inpf01, digits=12)
#or read in the be beast tree with the treeio package, this requires  R v4
bt_in02 <- treeio::read.beast("wd04_inpf01")
###########################################################################

treenm <- "phyA"
#define output file name
flnm02 <- c(paste("treewith_nodelables_",treenm,".svg",  sep = ""))
flnm03 <- c(paste("treewith_nodelables_",treenm,".png",  sep = ""))
# paste paths together
wd05 <- paste(wd00,"/",wd03,sep="")
#paste path and filename together
pth02_flnm02 <- paste(wd05,"/",flnm02,sep="")
pth02_flnm03 <- paste(wd05,"/",flnm03,sep="")
############ start plot phyA
#while (!is.null(dev.list()))  dev.off() 

devSVG(pth02_flnm02,
       width=(2*1.0*8.2677),height=(4*1.0*2.9232))

#define the plotting area with par settings
op <- par(mfrow=c(1,1), # set number of panes inside the plot - i.e. c(2,2) would make four panes for plots
          oma=c(1,1,0,0), # set outer margin (the margin around the combined plot area) - higher numbers increase the number of lines
          mar=c(5,5,5,5) # set the margin around each individual plot 
)
#https://cran.r-project.org/web/packages/ape/ape.pdf
#read in using ape package
phyA <- ape::read.nexus(wd04_inpf01)
#order the nodes in decreasing order - i.e. ladderize right
phyA <- ape::ladderize(phyA, right = TRUE)
# add node labels
plot (phyA)
ape::nodelabels()
#apply the par settings for the plot as defined above.
par(op)
# end svg file to save as
dev.off()  
############ end plot phyA
#Try a png plot
png(
  filename=pth02_flnm03,
  #width=(2*1.6*8.2677),
  width=3508, #height for 300 px resolution
  height=2480, #width for 300 px resolution
  units="px",
  res=300)

#define the plotting area with par settings
op <- par(mfrow=c(1,1), # set number of panes inside the plot - i.e. c(2,2) would make four panes for plots
          oma=c(1,1,0,0), # set outer margin (the margin around the combined plot area) - higher numbers increase the number of lines
          mar=c(5,5,5,5) # set the margin around each individual plot 
)
# add node labels
plot (phyA)
ape::nodelabels()
#apply the par settings for the plot as defined above.
par(op)
# end svg file to save as
dev.off()  

#the package 'tidytree' can get all information fro the beast tree
# and arrange it in a tibble
# Instead of using 'tidytree' the package 'ips' appears to be able to read the
# beast tree in a similar way to produce a table with all meta information
# for each node
# Otherwise:
# require(tidytree)
# d <- as_tibble(phyA)
# use the 'ips' package to read the meta information in the tree
# the number of digits needs to be fairly high to get all the low
# rates
bt_in01 <- ips:::read.beast.table(wd04_inpf01, digits = 12)
#make it a data frame
df_in02 <- as.data.frame(bt_in01)
#head(df_in02,4)
#get the clades that are either the root or the PDV clade or the CDV clade
vl_root_hgt <- df_in02$height[match(126,df_in02$node)]
vl_PDV_hgt <- df_in02$height[match(226,df_in02$node)]
vl_CDV_hgt <- df_in02$height[match(127,df_in02$node)]

# check the working directory
getwd()
#list the files in the directory with tree files
fl_in_PDVout10 <- list.files(wd02)
#grep for the relaxed and strict clock trees
#add these elements to a vector
fl_sr_t01 <- fl_in_PDVout10[grepl("PDVpos12_*.*cd*.*F.comb.tre",fl_in_PDVout10)]
# grep the files that do not have 'bdm' in the file name
fl_sr_t02 <- fl_sr_t01[!grepl("PDVpos12_*.*bdm*.*.comb.tre",fl_sr_t01)]

# make empty lists
lst_rot_hgt <- list()
lst_PDV_hgt <- list()
lst_CDV_hgt <- list()
# make empty lists
lst_rot_hgtmn <- list()
lst_PDV_hgtmn <- list()
lst_CDV_hgtmn <- list()
# make empty lists
lst_rot_hgtmx <- list()
lst_PDV_hgtmx <- list()
lst_CDV_hgtmx <- list()
#set i to 1
i <- 1
#iterate over files in list of files
for (i in fl_sr_t02)
{  
  print(i)
  #define input file to read in
  #notice that only the trees run in a relaxed clock model setting has 
  # rates on the branches. The trees with strict clock models do not have rates
  # on the branches
  inpf01 <- i
  #paste path and filename together
  wd04_inpf01 <- paste(wd04,"/",inpf01,sep="")
  #read in the file
  bt_in01 <- ips:::read.beast.table(wd04_inpf01, digits = 12)
  df_in02 <- as.data.frame(bt_in01)
  #get the values for heights for the nodes
  vl_root_hgt <- df_in02$height[match(126,df_in02$node)]
  vl_PDV_hgt <- df_in02$height[match(226,df_in02$node)]
  vl_CDV_hgt <- df_in02$height[match(127,df_in02$node)]
  #get the values for min heights for the nodes
  vl_root_hgtmn <- df_in02$`height_95%_HPD_MIN`[match(126,df_in02$node)]
  vl_PDV_hgtmn <- df_in02$`height_95%_HPD_MIN`[match(226,df_in02$node)]
  vl_CDV_hgtmn <- df_in02$`height_95%_HPD_MIN`[match(127,df_in02$node)]
  #get the values for min heights for the nodes
  vl_root_hgtmx <- df_in02$`height_95%_HPD_MAX`[match(126,df_in02$node)]
  vl_PDV_hgtmx <- df_in02$`height_95%_HPD_MAX`[match(226,df_in02$node)]
  vl_CDV_hgtmx <- df_in02$`height_95%_HPD_MAX`[match(127,df_in02$node)]
  
  #Add to the list
  lst_rot_hgt[[i]] <- vl_root_hgt
  lst_PDV_hgt[[i]] <- vl_PDV_hgt
  lst_CDV_hgt[[i]] <- vl_CDV_hgt
  #Add to the list
  lst_rot_hgtmn[[i]] <- vl_root_hgtmn
  lst_PDV_hgtmn[[i]] <- vl_PDV_hgtmn
  lst_CDV_hgtmn[[i]] <- vl_CDV_hgtmn
  #Add to the list
  lst_rot_hgtmx[[i]] <- vl_root_hgtmx
  lst_PDV_hgtmx[[i]] <- vl_PDV_hgtmx
  lst_CDV_hgtmx[[i]] <- vl_CDV_hgtmx
}
#unlist all first elements from the generated list
vhlrh <- unlist(lapply(lst_rot_hgt,'[[',1))
vhlPh <- unlist(lapply(lst_PDV_hgt,'[[',1))
vhlCh <- unlist(lapply(lst_CDV_hgt,'[[',1))
#unlist all first elements from the generated list
vhlrhmn <- unlist(lapply(lst_rot_hgtmn,'[[',1))
vhlPhmn <- unlist(lapply(lst_PDV_hgtmn,'[[',1))
vhlChmn <- unlist(lapply(lst_CDV_hgtmn,'[[',1))
#unlist all first elements from the generated list
vhlrhmx <- unlist(lapply(lst_rot_hgtmx,'[[',1))
vhlPhmx <- unlist(lapply(lst_PDV_hgtmx,'[[',1))
vhlChmx <- unlist(lapply(lst_CDV_hgtmx,'[[',1))
#make the lists dataframes
df_vhlrh <- as.data.frame(vhlrh)
df_vhlPh <- as.data.frame(vhlPh)
df_vhlCh <- as.data.frame(vhlCh)
#make the lists dataframes
df_vhlrhmn <- as.data.frame(vhlrhmn)
df_vhlPhmn <- as.data.frame(vhlPhmn)
df_vhlChmn <- as.data.frame(vhlChmn)
#make the lists dataframes
df_vhlrhmx <- as.data.frame(vhlrhmx)
df_vhlPhmx <- as.data.frame(vhlPhmx)
df_vhlChmx <- as.data.frame(vhlChmx)
#combine them by columns
df_rPCh <- cbind(df_vhlrh,df_vhlPh,df_vhlCh,
                 df_vhlrhmn,df_vhlPhmn,df_vhlChmn,
                 df_vhlrhmx,df_vhlPhmx,df_vhlChmx)
#change the column names
colnames(df_rPCh) <- c("root","PDV","CDV",
                       "rootmn","PDVmn","CDVmn",
                       "rootmx","PDVmx","CDVmx")
#see it as a boxplot
boxplot(df_rPCh)

#use gather in tidyr package to rearrange dataframe from wide to long
#http://www.cookbook-r.com/Manipulating_data/Converting_data_between_wide_and_long_format/
library(tidyr)
#rearrange the data frame in a long format to be able to use the 
#data frame in the ggplot 
df_rPCh02 <- tidyr::gather(df_rPCh,clade, node_age,root:CDV, factor_key=T)
#assign the data frame to a new object
df_rPCh01 <- df_rPCh
# assign the row names to a column
df_rPCh01$tfnm <- rownames(df_rPCh)
#rearrange the data frame
df_rPCh03 <- tidyr::gather(df_rPCh01,clade, node_age,root:CDV, factor_key=T)
# make empty columns
df_rPCh03$semx <- NA
df_rPCh03$semn <- NA
#if column is matching then add value to the matched column
df_rPCh03$semx[df_rPCh03$clade=="root"] <- df_rPCh03$rootmx[df_rPCh03$clade=="root"]
df_rPCh03$semx[df_rPCh03$clade=="PDV"] <- df_rPCh03$PDVmx[df_rPCh03$clade=="PDV"]
df_rPCh03$semx[df_rPCh03$clade=="CDV"] <- df_rPCh03$CDVmx[df_rPCh03$clade=="CDV"]
df_rPCh03$semn[df_rPCh03$clade=="root"] <- df_rPCh03$rootmn[df_rPCh03$clade=="root"]
df_rPCh03$semn[df_rPCh03$clade=="PDV"] <- df_rPCh03$PDVmn[df_rPCh03$clade=="PDV"]
df_rPCh03$semn[df_rPCh03$clade=="CDV"] <- df_rPCh03$CDVmn[df_rPCh03$clade=="CDV"]

#https://stackoverflow.com/questions/31630045/understanding-boxplot-with-jitter
library(ggplot2)
#use ggplot to plot the ages of the clades in the data frame prepared 
p2 <- ggplot(df_rPCh02, aes(x=clade, y=node_age)) +
  geom_point(aes(fill=clade), size=3, shape=21, colour="grey20",
             position=position_jitter(width=0.1, height=0.2)) +
  #geom_boxplot(outlier.colour=NA, fill=NA, colour="grey20") +
  labs(title="A - ages inferred on clades in BEAST trees")
#see the plot
p2
#change the axis labels
p2 <- p2 + labs(x = "clade", y = "node age in years before present day")
#see the plot
p2
#try again but add error bars

#https://rcompanion.org/handbook/C_04.html
#https://stackoverflow.com/questions/20197118/dotplot-with-error-bars-two-series-light-jitter
library(ggplot2)
# plot
p2.2 <- ggplot(data = df_rPCh03, aes(x = clade, y = node_age, 
                                     ymin = semn, ymax = semx, colour = tfnm)) +
  geom_point(position = position_dodge(width = 0.2)) +
  geom_errorbar(position = position_dodge(width = 0.2), width = 0.1) +
  labs(title="A - node age on clades in BEAST trees")
#coord_flip() +
#scale_colour_manual(values = c("blue", "red")) +
#theme_classic()
#see the plot
p2.2

#dev.off()
#dev.off()
p2.3 <- ggplot(data = df_rPCh03, aes(x = clade, y = node_age, 
                                     ymin = semn, ymax = semx, 
                                     fill = tfnm, colour = tfnm,
                                     shape = tfnm)) +
  
  geom_errorbar(position = position_dodge(width = 0.6), width = 0.1) +
  geom_point(position = position_dodge(width = 0.6), size=3) +
  #coord_flip() +
  # see this website: http://environmentalcomputing.net/plotting-with-ggplot-colours-and-symbols/
  # for help to adjust colours and shapes manually
  #use the 'rep' function to repeat a set of colours or numbers
  scale_colour_manual(values = c(rep(c("red","blue"),6))) +
  scale_shape_manual(values = rep(c(21,21,  22,22 , 25,25),2)) +
  scale_fill_manual(values =  c(rep(c("black"),6),rep(c("cyan"),6))) +
  labs(title="B - node age on clades in BEAST trees") +
  theme_classic()
#see the plot
p2.3
#adjust to get year
df_rPCh03$node_year_orig <- 2018-df_rPCh03$node_age
df_rPCh03$node_year_origmx <- 2018-df_rPCh03$semx
df_rPCh03$node_year_origmn <- 2018-df_rPCh03$semn
df_rPCh03$mdl <- gsub("noe","_",gsub("cd","c_",gsub("F[.]comb[.]tre","",gsub("PDVpos12_","",df_rPCh03$tfnm))))
#dev.off()
p2.4 <- ggplot(data = df_rPCh03, aes(x = clade, y = node_year_orig, 
                                     ymin = node_year_origmn, 
                                     ymax = node_year_origmx, 
                                     fill = mdl, colour = mdl,
                                     shape = mdl)) +
  
  geom_errorbar(position = position_dodge(width = 0.6), width = 0.1) +
  geom_point(position = position_dodge(width = 0.6), size=3) +
  #coord_flip() +
  # see this website: http://environmentalcomputing.net/plotting-with-ggplot-colours-and-symbols/
  # for help to adjust colours and shapes manually
  #use the 'rep' function to repeat a set of colours or numbers
  scale_colour_manual(values = c(rep(c("red","blue"),6))) +
  scale_shape_manual(values = rep(c(21,21,  22,22 , 25,25),2)) +
  scale_fill_manual(values =  c(rep(c("black"),6),rep(c("cyan"),6))) +
  labs(title="C - year of of origin on clades in BEAST trees") +
  labs(x = "clade", y = "Node origin, year AD")
#theme_classic()
#see the plot
p2.4


head(df_rPCh03,4)
df_rPCh03$prfmdl <- (df_rPCh03$mdl=="rc_cbs_GTR")
#dev.off()
p2.5 <- ggplot(data = df_rPCh03, aes(x = clade, y = node_year_orig, 
                                     ymin = node_year_origmn, 
                                     ymax = node_year_origmx, 
                                     fill = mdl, 
                                     shape = prfmdl, 
                                     colour = clade)) +
  
  geom_errorbar(position = position_dodge(width = 0.6), width = 0.1, color="black") +
  geom_point(position = position_dodge(width = 0.6), size=3 ) + #, 
  #color=as.numeric(as.factor(df_rPCh03$clade))
  #color=c(rep("red",12),rep("green",12),rep("blue",12))
  #) +
  #coord_flip() +
  # see this website: http://environmentalcomputing.net/plotting-with-ggplot-colours-and-symbols/
  # for help to adjust colours and shapes manually
  #use the 'rep' function to repeat a set of colours or numbers
  #scale_colour_manual(values = as.numeric(as.factor(df_rPCh03$clade))) +
  #scale_colour_manual(values = as.numeric(as.factor(df_rPCh03$prfmdl))) +
  #scale_shape_manual(values = c(21,rep(22,11))) +
  #scale_fill_manual(values = c("black",rep("red",11),"black",rep("green",11),"black",rep("blue",11)) ) +
#scale_fill_manual(values =  as.numeric(as.factor(df_rPCh03$prfmdl))) +
labs(title="D - year of of origin on clades in BEAST trees") +
  labs(x = "clade", y = "Node origin, year AD")
#theme_classic()
#see the plot
p2.5


#substract from present day
df_rPCh02$node_age2 <- 2018-df_rPCh02$node_age
#use ggplot to plot the ages of the clades in the data frame prepared 
p3 <- ggplot(df_rPCh02, aes(x=clade, y=node_age2)) +
  geom_point(aes(fill=clade), size=3, shape=21, colour="grey20",
             position=position_jitter(width=0.1, height=0.2)) +
  #geom_boxplot(outlier.colour=NA, fill=NA, colour="grey20") +
  labs(title="B - year of of origin on clades in BEAST trees")
#see the plot
p3
#change the axis labels
p3 <- p3 + labs(x = "clade", y = "Node origin, year AD")
#see the plot
p3

library("gridExtra")
p2_p3 <- gridExtra::grid.arrange(p2, p3, 
                                 ncol = 1, nrow = 2)

#get a list of the trees files with relaxed clocks
#add these elements to a vector
fl_r_t01 <- fl_in_PDVout10[grepl("PDVpos12_*.rcd*.*F.comb.tre",fl_in_PDVout10)]
#exclude trees with 'bdm' in the filename
fl_r_t03 <- fl_r_t01[!grepl("PDVpos12_*.rcdbdm*.*F.comb.tre",fl_r_t01)]

dev.off()
#define file name to print to
flnm05 <- "plotD_age_on_clades_from_pathsmpl_BEAST_tres.svg"
#paste path and plot name together
pth02_flnm05 <- paste(wd00,"/",wd03,"/",flnm05,sep="")
#write to an svg file
RSvgDevice::devSVG(pth02_flnm05,
                   width=(2*1.0*8.2677),height=(4*1.0*2.9232))

#define the plotting area with par settings
op <- par(mfrow=c(1,1), # set number of panes inside the plot - i.e. c(2,2) would make four panes for plots
          oma=c(1,1,0,0), # set outer margin (the margin around the combined plot area) - higher numbers increase the number of lines
          mar=c(5,5,5,5) # set the margin around each individual plot 
)
#https://cran.r-project.org/web/packages/ape/ape.pdf
# add node labels
plot (p2.5)
#apply the par settings for the plot as defined above.
par(op)
# end svg file to save as
dev.off() 


#install.packages
if(!require(tidyr)){
  install.packages("tidyr")
  library(tidyr)
}

#install.packages
if(!require(dplyr)){
  install.packages("dplyr")
  library(dplyr)
}

library(plyr)

library(tidyr)

#install.packages
if(!require(reshape)){
  install.packages("reshape")
  library(reshape)
}

#make an empty list to contain all generated data frames
ls_df_rc_trees <- list()
#iterate over files in list
for (file in fl_r_t03)
{
  print(file)
  #add filename to a variable
  inpf01 <- file
  #paste filename and path togetehr
  wd04_inpf01 <- paste(wd04,"/",inpf01,sep="")
  #read in the file
  bt_in01 <- ips:::read.beast.table(wd04_inpf01, digits = 12)
  #make it a data frame
  df_in02 <- as.data.frame(bt_in01)
  #set NAs to zero
  df_in02$rate_median[is.na(df_in02$rate_median)] <- 0 
  # and set rates that equal one to zero
  df_in02$rate[df_in02$rate==1] <- 0
  #add the data frame to the list
  ls_df_rc_trees[[file]] <- df_in02
}
#count the number if data frames stored in this list
length(ls_df_rc_trees)
#assmebling all data frames in the list to a single data frame
#by making it a data table
#https://itsalocke.com/blog/r-quick-tip-collapse-a-lists-of-data.frames-with-data.table/
dt<-data.table::rbindlist(ls_df_rc_trees, 
                          use.names=TRUE, fill=TRUE, idcol="treesfile")
# Then make it a data frame
df_in03 <- as.data.frame(dt)
colnames(df_in03)
table(cut(df_in03$rate, br))
as.data.frame(table(cut(df_in03$rate, breaks=seq(floor(min(df_in03$rate)),
                                                 round(max(df_in03$rate),digits=8), 
                                                 by=round(max(df_in03$rate),digits=8)/10))))

#plot the rates
#https://www.r-bloggers.com/2012/12/density-plot-with-ggplot/
p04 <- ggplot(df_in03, aes(x=rate, y=)) + 
  geom_density(aes(group=treesfile, colour=treesfile, 
                   fill=treesfile), alpha=0.3) + 
  labs(title="A - substitution rate",
       x = "rate, substitutions per site per year")
#see the plot
p04


#plot the median rates
p05 <- ggplot(df_in03, aes(x=rate)) + 
  geom_density(aes(group=treesfile, colour=treesfile, fill=treesfile), alpha=0.5) +
  labs(title="A - substitution rate",
       x = "rate, substitutions per site per year")
#see the plot
p05


# make a density plot . See: https://stats.stackexchange.com/questions/172311/r-geom-density-values-in-y-axis
# also see: #https://www.r-bloggers.com/2012/12/density-plot-with-ggplot/
p04 <- ggplot(df_in03)
p04 <- p04 + geom_density(aes(x=rate, y=..scaled.., fill=treesfile,
                              color=treesfile), alpha=0.2) +
  labs(title="A - substitution rate",
       x = "rate, substitutions per site per year",
       y = "proportion of rates counted")

p04 <- p04 + theme_bw()
p04

p06 <- ggplot(df_in03) + 
  #geom_histogram(breaks=breaks,aes(x=vector,y=..density..), position="identity") + 
  geom_histogram(aes(x=rate,group=treesfile, colour=treesfile, fill=treesfile), 
                 alpha=0.4,bins=1200) +
  # geom_density(aes(x=rate,group=treesfile, colour=treesfile, fill=treesfile), 
  #              alpha=0.4,inherit.aes = F) +
  labs(title="B - substitution rate",
       x = "rate, substitutions per site per year")
#see the plot
p06

library("gridExtra")
p05_p06 <- gridExtra::grid.arrange(p05, p06, 
                                   ncol = 1, nrow = 2)
#define output file
otfl04 <- "plot_subst_rates_BEAST_PDVtrees_2021jan04.png"
#paste path and filename together
pthwd05_otfl04 <- paste(wd05,"/",otfl04,sep="")
#
# save the plot using ggsave
ggplot2::ggsave(pthwd05_otfl04, p05_p06,
                height = 290,
                width = 210,
                units = "mm",
                dpi=300)




#modify the data frame
#set NAs to zero
df_in02$rate_median[is.na(df_in02$rate_median)] <- 0 
# and set rates that equal one to zero
df_in02$rate[df_in02$rate==1] <- 0

colnames(df_in02)
## - Tryout with ggplot2 for rate_median
library(ggplot2)
ggplot(df_in02, aes(x = rate_median)) + 
  geom_density(alpha = 0.5)
## - Tryout with ggplot2 for rate
library(ggplot2)
ggplot(df_in02, aes(x = rate)) + 
  geom_density(alpha = 0.5)

#define filename for file with marginal likelihood values
inf03 <- "marginal_lkhoods_tmp08.txt"
#paste together with path
pth02_flnm04 <- paste(wd00,"/",inf03,sep="")
#read in file with marginal likelihood values
df_fl02 <- read.table(pth02_flnm04)
#get the rownames
rwnmrPC <- rownames(df_rPCh)
#sustitute in column, escape points
df_rPCh$filnm1 <- gsub("[.]comb[.]tre","",rwnmrPC)
#sustitute in column, escape points
df_in03$filnm1 <- gsub("[.]comb[.]tre","",df_in03$treesfile)
df_fl02$filnm1 <- gsub("ss$","",df_fl02$V1)
#match to dataframe
df_rPCh$maliv <- df_fl02$V6[match(df_rPCh$filnm1,df_fl02$filnm1)]
#round marginal likelihood values
df_rPCh$maliv2 <- round(df_rPCh$maliv,digits=1)
#calculate year of origin of clade
df_rPCh$yr_orig_root <- 2018-df_rPCh$root
df_rPCh$yr_orig_PDV <- 2018-df_rPCh$PDV
df_rPCh$yr_orig_CDV <- 2018-df_rPCh$CDV
#round all years estimated
df_rPCh$yr_orig_root <- round(df_rPCh$yr_orig_root,digits = 0)
df_rPCh$yr_orig_PDV <- round(df_rPCh$yr_orig_PDV,digits = 0)
df_rPCh$yr_orig_CDV <- round(df_rPCh$yr_orig_CDV,digits = 0)
#substitute in filename
modnm01 <- gsub("PDVpos12_","",df_rPCh$filnm1)
# get first 2 letters to get clock model
df_rPCh$clckmodl <- substr(modnm01, 1, 2)
# get the 4th to 6th letters to get Prior Tree model
df_rPCh$ptmodl <- substr(modnm01, 4, 6)
# get the 10th to 12th letters to get nucleotide subst model
df_rPCh$sbtsmodl <- substr(modnm01, 10, 12)
#round  treeheight
df_rPCh$root <- round(df_rPCh$root, digits = 1)
df_rPCh$PDV <- round(df_rPCh$PDV, digits = 1)
df_rPCh$CDV <- round(df_rPCh$CDV, digits = 1)
#colnames(df_rPCh)
#define columns to keep
keeps <- c("maliv2",
           "root",
           "yr_orig_root",
           "yr_orig_PDV",
           "yr_orig_CDV",
           "clckmodl",
           "ptmodl",
           "sbtsmodl",
           "PDV",
           "CDV")
#only keep selected columns
df_rPCh03 <- df_rPCh[keeps]
colnames(df_rPCh03)
#reorder columns
df_rPCh04 <- df_rPCh03[ , c("clckmodl",
                            "ptmodl",
                            "sbtsmodl",
                            "root",
                            "maliv2",
                            "yr_orig_root",
                            "yr_orig_PDV",
                            "yr_orig_CDV",
                            "PDV",
                            "CDV")]
#change the column names
colnames(df_rPCh04) <- c("clock"	,"PriorTreeModel"	,
                         "Nucleotidesubstitutionmodel"	,"TreeHeightyears",
                         "Marginal_likelihood",
                         "Year_of_origin_DV",
                         "Year_of_origin_PDV",
                         "Year_of_origin_CDV",
                         "age_of_PDV",
                         "age_of_CDV")
#define an output file name
flnm04 <- "PDVout11_table01.csv"
#paste together with path
pth03_flnm04 <- paste(wd05,"/",flnm04,sep="")
#write a csv file
write.csv(df_rPCh04, file=pth03_flnm04)




##




